@@ -31,8 +31,8 @@ class ProxySettingsWidget : public AbstractAccountParametersWidget
 
 public:
     explicit ProxySettingsWidget(ParameterEditModel *model,
-                                 QWidget *parent = 0);
-    virtual ~ProxySettingsWidget();
+                                 QWidget *parent = nullptr);
+    ~ProxySettingsWidget() override;
 
 private:
     Q_DISABLE_COPY(ProxySettingsWidget)
