@@ -30,8 +30,8 @@ class SipeAdvancedSettingsWidget : public AbstractAccountParametersWidget
     Q_OBJECT
 
 public:
-    explicit SipeAdvancedSettingsWidget(ParameterEditModel *model, QWidget *parent = 0);
-    virtual ~SipeAdvancedSettingsWidget();
+    explicit SipeAdvancedSettingsWidget(ParameterEditModel *model, QWidget *parent = nullptr);
+    ~SipeAdvancedSettingsWidget() override;
 
 private:
     Q_DISABLE_COPY(SipeAdvancedSettingsWidget)
