@@ -31,11 +31,11 @@ class YahooMainOptionsWidget : public AbstractAccountParametersWidget
     Q_OBJECT
 
 public:
-    explicit YahooMainOptionsWidget(ParameterEditModel* model, QWidget* parent = 0);
-    virtual ~YahooMainOptionsWidget();
+    explicit YahooMainOptionsWidget(ParameterEditModel* model, QWidget* parent = nullptr);
+    ~YahooMainOptionsWidget() override;
 
-    virtual void submit() override;
-    virtual QString defaultDisplayName() const override;
+    void submit() override;
+    QString defaultDisplayName() const override;
 private:
     Q_DISABLE_COPY(YahooMainOptionsWidget)
     Ui::YahooMainOptionsWidget* m_ui;
