@@ -31,9 +31,9 @@ class SipeAccountUiPlugin : public AbstractAccountUiPlugin
 
 public:
     SipeAccountUiPlugin(QObject *parent, const QVariantList &);
-    virtual ~SipeAccountUiPlugin();
+    ~SipeAccountUiPlugin() override;
 
-    virtual AbstractAccountUi* accountUi(const QString &connectionManager, const QString &protocol, const QString &serviceName) override;
+    AbstractAccountUi* accountUi(const QString &connectionManager, const QString &protocol, const QString &serviceName) override;
 
 private:
     Q_DISABLE_COPY(SipeAccountUiPlugin)
