@@ -38,8 +38,8 @@ public:
     ParameterItem(const Tp::ProtocolParameter &parameter,
                   const Tp::Profile::Parameter &profileParameter,
                   const QVariant &originalValue,
-                  QObject *parent = 0);
-    virtual ~ParameterItem();
+                  QObject *parent = nullptr);
+    ~ParameterItem() override;
 
     QString name() const;
     QString localizedName() const;
